# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_enrichment_coverage_response import ReportingEnrichmentCoverageResponse

class TestReportingEnrichmentCoverageResponse(unittest.TestCase):
    """ReportingEnrichmentCoverageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingEnrichmentCoverageResponse:
        """Test ReportingEnrichmentCoverageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingEnrichmentCoverageResponse`
        """
        model = ReportingEnrichmentCoverageResponse()
        if include_optional:
            return ReportingEnrichmentCoverageResponse(
                by_client = [
                    neurograph.v1.models.reporting/client_enrichment_coverage.reporting.ClientEnrichmentCoverage(
                        account_uid = '', 
                        client_uid = '', 
                        enriched_count = 56, 
                        enriched_percentage = 1.337, 
                        not_enriched_count = 56, 
                        total_products = 56, )
                    ],
                cached = True,
                error = '',
                query_time_ms = 56,
                summary = neurograph.v1.models.reporting/enrichment_coverage_summary.reporting.EnrichmentCoverageSummary(
                    overall_enriched_percent = 1.337, 
                    total_clients = 56, 
                    total_enriched = 56, 
                    total_not_enriched = 56, 
                    total_products = 56, )
            )
        else:
            return ReportingEnrichmentCoverageResponse(
        )
        """

    def testReportingEnrichmentCoverageResponse(self):
        """Test ReportingEnrichmentCoverageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
