# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_gamma_design_settings import OrganizationsGammaDesignSettings

class TestOrganizationsGammaDesignSettings(unittest.TestCase):
    """OrganizationsGammaDesignSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGammaDesignSettings:
        """Test OrganizationsGammaDesignSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGammaDesignSettings`
        """
        model = OrganizationsGammaDesignSettings()
        if include_optional:
            return OrganizationsGammaDesignSettings(
                blocks = neurograph.v1.models.organizations/gamma_block_settings.organizations.GammaBlockSettings(
                    block_border = 56, 
                    block_fill = 56, 
                    block_fill_color = '', 
                    block_shadow = 56, ),
                buttons = neurograph.v1.models.organizations/gamma_button_settings.organizations.GammaButtonSettings(
                    button_color = '', 
                    button_shape = 56, 
                    link_color = '', ),
                cards = neurograph.v1.models.organizations/gamma_card_settings.organizations.GammaCardSettings(
                    accent_image_shape = 56, 
                    card_border = 56, 
                    card_border_color = '', 
                    card_shadow = 56, 
                    card_transparency = 56, 
                    roundness = 56, )
            )
        else:
            return OrganizationsGammaDesignSettings(
        )
        """

    def testOrganizationsGammaDesignSettings(self):
        """Test OrganizationsGammaDesignSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
