# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.personas_seed_get_many_response import PersonasSeedGetManyResponse

class TestPersonasSeedGetManyResponse(unittest.TestCase):
    """PersonasSeedGetManyResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PersonasSeedGetManyResponse:
        """Test PersonasSeedGetManyResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PersonasSeedGetManyResponse`
        """
        model = PersonasSeedGetManyResponse()
        if include_optional:
            return PersonasSeedGetManyResponse(
                data = [
                    neurograph.v1.models.personas/seed.personas.Seed(
                        client_id = 'cli_5678', 
                        error = '', 
                        id = 'per_1234', 
                        is_active = True, 
                        ts_created = 56, 
                        uid = 'strong-gym-guy', )
                    ],
                error = '',
                query_limit = 56,
                query_offset = 56,
                total_rows = 56
            )
        else:
            return PersonasSeedGetManyResponse(
        )
        """

    def testPersonasSeedGetManyResponse(self):
        """Test PersonasSeedGetManyResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
