# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reporting_client_breakdown import ReportingClientBreakdown
from neurograph.v1.models.reporting_date_range import ReportingDateRange
from neurograph.v1.models.reporting_org_breakdown import ReportingOrgBreakdown
from neurograph.v1.models.reporting_portfolio_metrics import ReportingPortfolioMetrics
from typing import Optional, Set
from typing_extensions import Self

class ReportingPortfolioActivityResponse(BaseModel):
    """
    ReportingPortfolioActivityResponse
    """ # noqa: E501
    by_client: Optional[List[ReportingClientBreakdown]] = None
    by_org: Optional[List[ReportingOrgBreakdown]] = None
    cached: Optional[StrictBool] = None
    date_range: Optional[ReportingDateRange] = None
    error: Optional[StrictStr] = None
    portfolio: Optional[ReportingPortfolioMetrics] = None
    query_time_ms: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["by_client", "by_org", "cached", "date_range", "error", "portfolio", "query_time_ms"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingPortfolioActivityResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in by_client (list)
        _items = []
        if self.by_client:
            for _item_by_client in self.by_client:
                if _item_by_client:
                    _items.append(_item_by_client.to_dict())
            _dict['by_client'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in by_org (list)
        _items = []
        if self.by_org:
            for _item_by_org in self.by_org:
                if _item_by_org:
                    _items.append(_item_by_org.to_dict())
            _dict['by_org'] = _items
        # override the default output from pydantic by calling `to_dict()` of date_range
        if self.date_range:
            _dict['date_range'] = self.date_range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of portfolio
        if self.portfolio:
            _dict['portfolio'] = self.portfolio.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingPortfolioActivityResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "by_client": [ReportingClientBreakdown.from_dict(_item) for _item in obj["by_client"]] if obj.get("by_client") is not None else None,
            "by_org": [ReportingOrgBreakdown.from_dict(_item) for _item in obj["by_org"]] if obj.get("by_org") is not None else None,
            "cached": obj.get("cached"),
            "date_range": ReportingDateRange.from_dict(obj["date_range"]) if obj.get("date_range") is not None else None,
            "error": obj.get("error"),
            "portfolio": ReportingPortfolioMetrics.from_dict(obj["portfolio"]) if obj.get("portfolio") is not None else None,
            "query_time_ms": obj.get("query_time_ms")
        })
        return _obj


