# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_buyer_scenario import ReportingBuyerScenario

class TestReportingBuyerScenario(unittest.TestCase):
    """ReportingBuyerScenario unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingBuyerScenario:
        """Test ReportingBuyerScenario
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingBuyerScenario`
        """
        model = ReportingBuyerScenario()
        if include_optional:
            return ReportingBuyerScenario(
                color = '',
                complexity = '',
                description = '',
                icon = '',
                id = '',
                intent = '',
                persona_context = '',
                persona_id = '',
                purchase_likelihood = 1.337,
                tags = [
                    ''
                    ],
                timeline = '',
                title = '',
                trigger_event = ''
            )
        else:
            return ReportingBuyerScenario(
        )
        """

    def testReportingBuyerScenario(self):
        """Test ReportingBuyerScenario"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
