# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.reports_api import ReportsApi


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportsApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_public_reports_id_get(self) -> None:
        """Test case for api_v1_public_reports_id_get

        Get Public Report
        """
        pass

    def test_api_v1_reports_facets_get(self) -> None:
        """Test case for api_v1_reports_facets_get

        Get Report Facets
        """
        pass

    def test_api_v1_reports_generate_post(self) -> None:
        """Test case for api_v1_reports_generate_post

        Generate Report via Agent
        """
        pass

    def test_api_v1_reports_get(self) -> None:
        """Test case for api_v1_reports_get

        List Report Artifacts
        """
        pass

    def test_api_v1_reports_id_agent_status_get(self) -> None:
        """Test case for api_v1_reports_id_agent_status_get

        Get Agent Report Status
        """
        pass

    def test_api_v1_reports_id_delete(self) -> None:
        """Test case for api_v1_reports_id_delete

        Delete Report Artifact
        """
        pass

    def test_api_v1_reports_id_generate_summary_post(self) -> None:
        """Test case for api_v1_reports_id_generate_summary_post

        Generate Report Summary
        """
        pass

    def test_api_v1_reports_id_get(self) -> None:
        """Test case for api_v1_reports_id_get

        Get Report Artifact
        """
        pass

    def test_api_v1_reports_id_markdown_get(self) -> None:
        """Test case for api_v1_reports_id_markdown_get

        Get Report Markdown
        """
        pass

    def test_api_v1_reports_id_markdown_put(self) -> None:
        """Test case for api_v1_reports_id_markdown_put

        Update Report Markdown
        """
        pass

    def test_api_v1_reports_id_og_image_get(self) -> None:
        """Test case for api_v1_reports_id_og_image_get

        Get Report OG Image
        """
        pass

    def test_api_v1_reports_id_put(self) -> None:
        """Test case for api_v1_reports_id_put

        Update Report Artifact
        """
        pass

    def test_api_v1_reports_id_regenerate_og_image_post(self) -> None:
        """Test case for api_v1_reports_id_regenerate_og_image_post

        Regenerate Report OG Image
        """
        pass

    def test_api_v1_reports_id_share_get(self) -> None:
        """Test case for api_v1_reports_id_share_get

        Get Report Share Link
        """
        pass

    def test_api_v1_reports_id_sync_agent_post(self) -> None:
        """Test case for api_v1_reports_id_sync_agent_post

        Sync Agent Report Results
        """
        pass

    def test_api_v1_reports_post(self) -> None:
        """Test case for api_v1_reports_post

        Create Report Artifact
        """
        pass

    def test_api_v1_reports_search_get(self) -> None:
        """Test case for api_v1_reports_search_get

        Search Report Artifacts
        """
        pass

    def test_share_report_id_get(self) -> None:
        """Test case for share_report_id_get

        Get Report OG Meta
        """
        pass


if __name__ == '__main__':
    unittest.main()
