# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.signal_client_signal_details_response import SignalClientSignalDetailsResponse

class TestSignalClientSignalDetailsResponse(unittest.TestCase):
    """SignalClientSignalDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SignalClientSignalDetailsResponse:
        """Test SignalClientSignalDetailsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SignalClientSignalDetailsResponse`
        """
        model = SignalClientSignalDetailsResponse()
        if include_optional:
            return SignalClientSignalDetailsResponse(
                cached = True,
                client_info = neurograph.v1.models.signal/client_info.signal.ClientInfo(
                    client_uid = '', 
                    domain = '', 
                    org_uid = '', ),
                daily_intent = [
                    neurograph.v1.models.signal/daily_intent_band.signal.DailyIntentBand(
                        avg_attention_seconds = 1.337, 
                        avg_engagement_score = 1.337, 
                        avg_pages_viewed = 1.337, 
                        avg_predicted_probability = 1.337, 
                        conversion_rate = 1.337, 
                        converted_visitors = 56, 
                        date = '', 
                        intent_band = '', 
                        visitor_count = 56, )
                    ],
                daily_purchases = [
                    neurograph.v1.models.signal/daily_purchase_metrics.signal.DailyPurchaseMetrics(
                        api_success_count = 56, 
                        api_success_rate = 1.337, 
                        avg_data_completeness = 1.337, 
                        avg_order_value = 1.337, 
                        date = '', 
                        new_customers = 56, 
                        predicted_revenue = 1.337, 
                        returning_customers = 56, 
                        total_purchases = 56, 
                        total_revenue = 1.337, )
                    ],
                date_range = neurograph.v1.models.signal/date_range.signal.DateRange(
                    end_date = '', 
                    start_date = '', ),
                error = '',
                persona_breakdown = [
                    neurograph.v1.models.signal/persona_conversion.signal.PersonaConversion(
                        avg_match_likelihood = 1.337, 
                        persona_name = '', 
                        purchase_count = 56, 
                        return_rate = 1.337, 
                        returning_count = 56, 
                        revenue = 1.337, )
                    ],
                query_time_ms = 56,
                totals = neurograph.v1.models.signal/client_signal_totals.signal.ClientSignalTotals(
                    conversions = neurograph.v1.models.signal/conversion_summary.signal.ConversionSummary(
                        api_success_rate = 1.337, 
                        avg_data_completeness = 1.337, 
                        new_customers = 56, 
                        predicted_revenue = 1.337, 
                        prediction_uplift_pct = 1.337, 
                        returning_customers = 56, 
                        returning_pct = 1.337, 
                        total_purchases = 56, 
                        total_revenue = 1.337, ), 
                    intent = neurograph.v1.models.signal/intent_summary.signal.IntentSummary(
                        avg_high_engagement = 1.337, 
                        avg_low_engagement = 1.337, 
                        avg_medium_engagement = 1.337, 
                        high_conversion_rate = 1.337, 
                        low_conversion_rate = 1.337, 
                        medium_conversion_rate = 1.337, 
                        total_high = 56, 
                        total_low = 56, 
                        total_medium = 56, ), )
            )
        else:
            return SignalClientSignalDetailsResponse(
        )
        """

    def testSignalClientSignalDetailsResponse(self):
        """Test SignalClientSignalDetailsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
