# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_persona_buyer_scenarios_response import ReportingPersonaBuyerScenariosResponse

class TestReportingPersonaBuyerScenariosResponse(unittest.TestCase):
    """ReportingPersonaBuyerScenariosResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPersonaBuyerScenariosResponse:
        """Test ReportingPersonaBuyerScenariosResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPersonaBuyerScenariosResponse`
        """
        model = ReportingPersonaBuyerScenariosResponse()
        if include_optional:
            return ReportingPersonaBuyerScenariosResponse(
                cached = True,
                error = '',
                meta = neurograph.v1.models.reporting/buyer_scenarios_meta.reporting.BuyerScenariosMeta(
                    client_id = '', 
                    data_date = '', 
                    generated_at = '', ),
                query_time_ms = 56,
                scenarios = [
                    neurograph.v1.models.reporting/buyer_scenario.reporting.BuyerScenario(
                        color = '', 
                        complexity = '', 
                        description = '', 
                        icon = '', 
                        id = '', 
                        intent = '', 
                        persona_context = '', 
                        persona_id = '', 
                        purchase_likelihood = 1.337, 
                        tags = [
                            ''
                            ], 
                        timeline = '', 
                        title = '', 
                        trigger_event = '', )
                    ],
                total_count = 56
            )
        else:
            return ReportingPersonaBuyerScenariosResponse(
        )
        """

    def testReportingPersonaBuyerScenariosResponse(self):
        """Test ReportingPersonaBuyerScenariosResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
