# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_report_generate_request import ReportsReportGenerateRequest

class TestReportsReportGenerateRequest(unittest.TestCase):
    """ReportsReportGenerateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsReportGenerateRequest:
        """Test ReportsReportGenerateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsReportGenerateRequest`
        """
        model = ReportsReportGenerateRequest()
        if include_optional:
            return ReportsReportGenerateRequest(
                analysis_type = 'cross_persona',
                brand_context = { },
                client_id = 'cli_4o5o5ENX3q3e8oosqlBKF7',
                custom_prompt = '',
                data_sources = [
                    neurograph.v1.models.reports/data_source_config.reports.DataSourceConfig(
                        client_id = 'cli_4o5o5ENX3q3e8oosqlBKF7', 
                        dataset_id = '', 
                        end_date = '2026-01-01', 
                        file_path = '', 
                        project_id = '', 
                        query = '', 
                        start_date = '2025-12-01', 
                        table_id = '', 
                        type = 'neurograph_pipeline', )
                    ],
                date_range = neurograph.v1.models.reports/date_range.reports.DateRange(
                    end = '2026-01-01', 
                    start = '2025-12-01', ),
                end_date = '2026-01-01',
                max_rows = 100000,
                name = 'Q4 2025 Cross-Persona Analysis',
                output_format = 'json',
                personas = [
                    ''
                    ],
                report_type = 'Cross-Persona Product Analysis',
                start_date = '2025-12-01'
            )
        else:
            return ReportsReportGenerateRequest(
        )
        """

    def testReportsReportGenerateRequest(self):
        """Test ReportsReportGenerateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
