# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_persona_demographics_response import ReportingPersonaDemographicsResponse

class TestReportingPersonaDemographicsResponse(unittest.TestCase):
    """ReportingPersonaDemographicsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPersonaDemographicsResponse:
        """Test ReportingPersonaDemographicsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPersonaDemographicsResponse`
        """
        model = ReportingPersonaDemographicsResponse()
        if include_optional:
            return ReportingPersonaDemographicsResponse(
                age_distribution = neurograph.v1.models.reporting/age_distribution_data.reporting.AgeDistributionData(
                    buckets = [
                        neurograph.v1.models.reporting/age_bucket.reporting.AgeBucket(
                            avg_pct = 1.337, 
                            bucket = '', 
                            comparison = '', 
                            customer_count = 56, 
                            delta = 1.337, 
                            percentage = 1.337, )
                        ], ),
                cached = True,
                error = '',
                gender_split = neurograph.v1.models.reporting/gender_split_data.reporting.GenderSplitData(
                    dominant_gender = '', 
                    female_count = 56, 
                    female_pct = 56, 
                    male_count = 56, 
                    male_pct = 56, 
                    total_count = 56, 
                    unknown_count = 56, ),
                geographic_distribution = neurograph.v1.models.reporting/geographic_distribution_data.reporting.GeographicDistributionData(
                    metro_areas = [
                        neurograph.v1.models.reporting/metro_area.reporting.MetroArea(
                            concentration_pct = 1.337, 
                            customer_count = 56, 
                            delta = 1.337, 
                            metro = '', 
                            rank = 56, 
                            state = '', )
                        ], 
                    other_markets = neurograph.v1.models.reporting/other_markets.reporting.OtherMarkets(
                        concentration_pct = 1.337, 
                        count = 56, 
                        customer_count = 56, ), ),
                income_bands = neurograph.v1.models.reporting/income_bands_data.reporting.IncomeBandsData(
                    bands = [
                        neurograph.v1.models.reporting/income_band.reporting.IncomeBand(
                            band = '', 
                            customer_count = 56, 
                            label = '', 
                            percentage = 1.337, )
                        ], ),
                meta = neurograph.v1.models.reporting/demographics_meta.reporting.DemographicsMeta(
                    client_uid = '', 
                    computed_metrics = neurograph.v1.models.reporting/computed_metrics.reporting.ComputedMetrics(
                        median_age = 1.337, 
                        median_income = 56, ), 
                    generated_at = '', 
                    organization_uid = '', 
                    partition_date = '', 
                    persona_id = '', 
                    persona_name = '', 
                    sample_size = 56, ),
                query_time_ms = 56
            )
        else:
            return ReportingPersonaDemographicsResponse(
        )
        """

    def testReportingPersonaDemographicsResponse(self):
        """Test ReportingPersonaDemographicsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
