# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reporting_daily_predictions import ReportingDailyPredictions
from neurograph.v1.models.reporting_date_range import ReportingDateRange
from neurograph.v1.models.reporting_model_job_stats import ReportingModelJobStats
from neurograph.v1.models.reporting_model_job_summary import ReportingModelJobSummary
from neurograph.v1.models.reporting_model_jobs_over_time import ReportingModelJobsOverTime
from neurograph.v1.models.reporting_model_version_stats import ReportingModelVersionStats
from typing import Optional, Set
from typing_extensions import Self

class ReportingModelInsightsResponse(BaseModel):
    """
    ReportingModelInsightsResponse
    """ # noqa: E501
    cached: Optional[StrictBool] = None
    daily_predictions: Optional[List[ReportingDailyPredictions]] = None
    date_range: Optional[ReportingDateRange] = None
    error: Optional[StrictStr] = None
    jobs_over_time: Optional[List[ReportingModelJobsOverTime]] = None
    query_time_ms: Optional[StrictInt] = None
    recent_jobs: Optional[List[ReportingModelJobSummary]] = None
    stats: Optional[ReportingModelJobStats] = None
    version_stats: Optional[List[ReportingModelVersionStats]] = None
    __properties: ClassVar[List[str]] = ["cached", "daily_predictions", "date_range", "error", "jobs_over_time", "query_time_ms", "recent_jobs", "stats", "version_stats"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingModelInsightsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in daily_predictions (list)
        _items = []
        if self.daily_predictions:
            for _item_daily_predictions in self.daily_predictions:
                if _item_daily_predictions:
                    _items.append(_item_daily_predictions.to_dict())
            _dict['daily_predictions'] = _items
        # override the default output from pydantic by calling `to_dict()` of date_range
        if self.date_range:
            _dict['date_range'] = self.date_range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in jobs_over_time (list)
        _items = []
        if self.jobs_over_time:
            for _item_jobs_over_time in self.jobs_over_time:
                if _item_jobs_over_time:
                    _items.append(_item_jobs_over_time.to_dict())
            _dict['jobs_over_time'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in recent_jobs (list)
        _items = []
        if self.recent_jobs:
            for _item_recent_jobs in self.recent_jobs:
                if _item_recent_jobs:
                    _items.append(_item_recent_jobs.to_dict())
            _dict['recent_jobs'] = _items
        # override the default output from pydantic by calling `to_dict()` of stats
        if self.stats:
            _dict['stats'] = self.stats.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in version_stats (list)
        _items = []
        if self.version_stats:
            for _item_version_stats in self.version_stats:
                if _item_version_stats:
                    _items.append(_item_version_stats.to_dict())
            _dict['version_stats'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingModelInsightsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cached": obj.get("cached"),
            "daily_predictions": [ReportingDailyPredictions.from_dict(_item) for _item in obj["daily_predictions"]] if obj.get("daily_predictions") is not None else None,
            "date_range": ReportingDateRange.from_dict(obj["date_range"]) if obj.get("date_range") is not None else None,
            "error": obj.get("error"),
            "jobs_over_time": [ReportingModelJobsOverTime.from_dict(_item) for _item in obj["jobs_over_time"]] if obj.get("jobs_over_time") is not None else None,
            "query_time_ms": obj.get("query_time_ms"),
            "recent_jobs": [ReportingModelJobSummary.from_dict(_item) for _item in obj["recent_jobs"]] if obj.get("recent_jobs") is not None else None,
            "stats": ReportingModelJobStats.from_dict(obj["stats"]) if obj.get("stats") is not None else None,
            "version_stats": [ReportingModelVersionStats.from_dict(_item) for _item in obj["version_stats"]] if obj.get("version_stats") is not None else None
        })
        return _obj


