# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.reporting_api import ReportingApi


class TestReportingApi(unittest.TestCase):
    """ReportingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportingApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_reporting_client_activity_post(self) -> None:
        """Test case for api_v1_reporting_client_activity_post

        Get Sessions and Purchases for a client from BigQuery (single call)
        """
        pass

    def test_api_v1_reporting_customer_insights_post(self) -> None:
        """Test case for api_v1_reporting_customer_insights_post

        Get Customer Insights for a client
        """
        pass

    def test_api_v1_reporting_daily_rollup_post(self) -> None:
        """Test case for api_v1_reporting_daily_rollup_post

        Get Daily Metrics for Client by Persona from BigQuery
        """
        pass

    def test_api_v1_reporting_data_availability_post(self) -> None:
        """Test case for api_v1_reporting_data_availability_post

        Get earliest data availability date for a client
        """
        pass

    def test_api_v1_reporting_enrichment_coverage_post(self) -> None:
        """Test case for api_v1_reporting_enrichment_coverage_post

        Get product enrichment coverage from BigQuery
        """
        pass

    def test_api_v1_reporting_model_insights_post(self) -> None:
        """Test case for api_v1_reporting_model_insights_post

        Get Model Insights
        """
        pass

    def test_api_v1_reporting_model_jobs_job_id_get(self) -> None:
        """Test case for api_v1_reporting_model_jobs_job_id_get

        Get Model Job Detail
        """
        pass

    def test_api_v1_reporting_model_predictions_client_id_account_id_assignment_date_get(self) -> None:
        """Test case for api_v1_reporting_model_predictions_client_id_account_id_assignment_date_get

        Get Model Prediction Detail
        """
        pass

    def test_api_v1_reporting_persona_buyer_scenarios_post(self) -> None:
        """Test case for api_v1_reporting_persona_buyer_scenarios_post

        Get persona buyer scenarios from BigQuery knowledge graph
        """
        pass

    def test_api_v1_reporting_persona_demographics_post(self) -> None:
        """Test case for api_v1_reporting_persona_demographics_post

        Get persona demographics data from BigQuery
        """
        pass

    def test_api_v1_reporting_persona_product_affinity_post(self) -> None:
        """Test case for api_v1_reporting_persona_product_affinity_post

        Get persona product affinity data from BigQuery
        """
        pass

    def test_api_v1_reporting_portfolio_activity_post(self) -> None:
        """Test case for api_v1_reporting_portfolio_activity_post

        Get portfolio-wide Sessions and Purchases with org/client breakdowns
        """
        pass

    def test_api_v1_reporting_product_affinity_post(self) -> None:
        """Test case for api_v1_reporting_product_affinity_post

        Get product affinity scores from BigQuery
        """
        pass

    def test_api_v1_reporting_purchases_post(self) -> None:
        """Test case for api_v1_reporting_purchases_post

        Get Purchase events for a client from BigQuery
        """
        pass

    def test_api_v1_reporting_sessions_post(self) -> None:
        """Test case for api_v1_reporting_sessions_post

        Get Session Init events for a client from BigQuery
        """
        pass


if __name__ == '__main__':
    unittest.main()
