# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow

class TestKnowledgeIngestRawRow(unittest.TestCase):
    """KnowledgeIngestRawRow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeIngestRawRow:
        """Test KnowledgeIngestRawRow
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeIngestRawRow`
        """
        model = KnowledgeIngestRawRow()
        if include_optional:
            return KnowledgeIngestRawRow(
                client_id = 'cli_12345',
                payload = neurograph.v1.models.payload.payload(),
                payload_hash = '',
                source_collection = 'cache_v0.9',
                source_ref_id = '52a0d225-...',
                source_schema = '@shopify/product'
            )
        else:
            return KnowledgeIngestRawRow(
        )
        """

    def testKnowledgeIngestRawRow(self):
        """Test KnowledgeIngestRawRow"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
