# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_report_generate_response import ReportsReportGenerateResponse

class TestReportsReportGenerateResponse(unittest.TestCase):
    """ReportsReportGenerateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsReportGenerateResponse:
        """Test ReportsReportGenerateResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsReportGenerateResponse`
        """
        model = ReportsReportGenerateResponse()
        if include_optional:
            return ReportsReportGenerateResponse(
                agent_report_id = 'rpt_606922a32d87',
                error = '',
                firestore_collection = 'client_reports',
                firestore_document_id = 'rpt_606922a32d87',
                message = 'Report generation started',
                report_id = 'rpt_123',
                status = 'pending',
                status_url = '/api/v1/reports/rpt_123'
            )
        else:
            return ReportsReportGenerateResponse(
        )
        """

    def testReportsReportGenerateResponse(self):
        """Test ReportsReportGenerateResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
